@@ -1,4 +1,4 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
 import httplib
 import base64
@@ -23,12 +23,8 @@ class ApiError(Exception):
             % (str(self.status), self.reason, self.payload)
         )
 
-###########################################################################
-## Main class                                                            ##
-
 
 class OsmApi:
-
     def __init__(
             self,
             username=None,
@@ -62,7 +58,7 @@ class OsmApi:
                 if l[0] == self._username:
                     self._password = l[1]
 
-        ## Changest informations
+        # Changest informations
         # auto create and close changesets
         self._changesetauto = changesetauto
         # tags for automatic created changesets
@@ -97,9 +93,9 @@ class OsmApi:
             self._changesetautoflush(True)
         return None
 
-    #######################################################################
-    # Capabilities                                                        #
-    #######################################################################
+    ##################################################
+    # Capabilities                                   #
+    ##################################################
 
     def Capabilities(self):
         """
@@ -108,7 +104,6 @@ class OsmApi:
         uri = "/api/capabilities"
         data = self._get(uri)
         data = xml.dom.minidom.parseString(data)
-        print data.getElementsByTagName("osm")
         data = data.getElementsByTagName("osm")[0]
         data = data.getElementsByTagName("api")[0]
         result = {}
@@ -116,7 +111,6 @@ class OsmApi:
             if elem.nodeType != elem.ELEMENT_NODE:
                 continue
             result[elem.nodeName] = {}
-            print elem.nodeName
             for k, v in elem.attributes.items():
                 try:
                     result[elem.nodeName][k] = float(v)
@@ -124,9 +118,9 @@ class OsmApi:
                     result[elem.nodeName][k] = v
         return result
 
-    #######################################################################
-    # Node                                                                #
-    #######################################################################
+    ##################################################
+    # Node                                           #
+    ##################################################
 
     def NodeGet(self, NodeId, NodeVersion=-1):
         """
@@ -220,9 +214,9 @@ class OsmApi:
             result[data[u"id"]] = data
         return result
 
-    #######################################################################
-    # Way                                                                 #
-    #######################################################################
+    ##################################################
+    # Way                                            #
+    ##################################################
 
     def WayGet(self, WayId, WayVersion=-1):
         """
@@ -311,9 +305,9 @@ class OsmApi:
             result[data[u"id"]] = data
         return result
 
-    #######################################################################
-    # Relation                                                            #
-    #######################################################################
+    ##################################################
+    # Relation                                       #
+    ##################################################
 
     def RelationGet(self, RelationId, RelationVersion=-1):
         """
@@ -425,9 +419,9 @@ class OsmApi:
             result[data[u"id"]] = data
         return result
 
-    #######################################################################
-    # Changeset                                                           #
-    #######################################################################
+    ##################################################
+    # Changeset                                      #
+    ##################################################
 
     def ChangesetGet(self, ChangesetId):
         """
@@ -443,7 +437,7 @@ class OsmApi:
         """
         Updates current changeset with ChangesetTags.
         """
-        if self._CurrentChangesetId == -1:
+        if not self._CurrentChangesetId:
             raise Exception("No changeset currently opened")
         if u"created_by" not in ChangesetTags:
             ChangesetTags[u"created_by"] = self._created_by
@@ -458,7 +452,7 @@ class OsmApi:
         Opens a changeset. Returns #ChangesetId.
         """
         if self._CurrentChangesetId:
-            raise Exception("Changeset alreadey opened")
+            raise Exception("Changeset already opened")
         if u"created_by" not in ChangesetTags:
             ChangesetTags[u"created_by"] = self._created_by
         result = self._put(
@@ -521,7 +515,9 @@ class OsmApi:
                 ChangesData[i]["data"].pop("version")
             else:
                 new_id = int(data[i].getAttribute("new_id"))
-                ChangesData[i]["data"]["version"] = new_id
+                ChangesData[i]["data"]["id"] = new_id
+                new_version = int(data[i].getAttribute("new_version"))
+                ChangesData[i]["data"]["version"] = new_version
         return ChangesData
 
     def ChangesetDownload(self, ChangesetId):
@@ -593,9 +589,9 @@ class OsmApi:
             result[tmpCS["id"]] = tmpCS
         return result
 
-    #######################################################################
-    # Other                                                               #
-    #######################################################################
+    ##################################################
+    # Other                                          #
+    ##################################################
 
     def Map(self, min_lon, min_lat, max_lon, max_lat):
         """
@@ -613,9 +609,9 @@ class OsmApi:
         data = self._get(uri)
         return self.ParseOsm(data)
 
-    #######################################################################
-    # Data parser                                                         #
-    #######################################################################
+    ##################################################
+    # Data parser                                    #
+    ##################################################
 
     def ParseOsm(self, data):
         """
@@ -684,9 +680,9 @@ class OsmApi:
                     })
         return result
 
-    #######################################################################
-    # Internal http function                                              #
-    #######################################################################
+    ##################################################
+    # Internal http function                         #
+    ##################################################
 
     def _do(self, action, OsmType, OsmData):
         if self._changesetauto:
@@ -738,7 +734,7 @@ class OsmApi:
         return self._changesetautoflush(True)
 
     def _changesetautoflush(self, force=False):
-        autosize = self._chnagesetautosize
+        autosize = self._changesetautosize
         while ((len(self._changesetautodata) >= autosize) or
                 (force and self._changesetautodata)):
             if self._changesetautocpt == 0:
@@ -826,9 +822,9 @@ class OsmApi:
     def _delete(self, path, data):
         return self._http('DELETE', path, True, data)
 
-    #######################################################################
-    # Internal dom function                                               #
-    #######################################################################
+    ##################################################
+    # Internal dom function                          #
+    ##################################################
 
     def _DomGetAttributes(self, DomElement):  # noqa
         """
@@ -920,9 +916,9 @@ class OsmApi:
         result[u"tag"] = self._DomGetTag(DomElement)
         return result
 
-    #######################################################################
-    # Internal xml builder                                                #
-    #######################################################################
+    ##################################################
+    # Internal xml builder                           #
+    ##################################################
 
     def _XmlBuild(self, ElementType, ElementData, WithHeaders=True):  # noqa
 
@@ -980,6 +976,3 @@ class OsmApi:
             .replace("<", "&lt;")
             .replace(">", "&gt;")
         )
-
-## End of main class                                                     ##
-###########################################################################
